Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(33)

Unified Diff: ui/ozone/public/ozone_platform.h

Issue 2420253002: Rename shell namespace to service_manager (Closed)
Patch Set: . Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/ozone/platform/drm/ozone_platform_gbm.cc ('k') | ui/ozone/public/ozone_platform.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/ozone/public/ozone_platform.h
diff --git a/ui/ozone/public/ozone_platform.h b/ui/ozone/public/ozone_platform.h
index f530af37d9d9a063fca34fde83a01eda59d68b52..93b08d22f757fa5d5ecfb372de6284fb698984e3 100644
--- a/ui/ozone/public/ozone_platform.h
+++ b/ui/ozone/public/ozone_platform.h
@@ -18,7 +18,7 @@ namespace IPC {
class MessageFilter;
}
-namespace shell {
+namespace service_manager {
class Connector;
class InterfaceRegistry;
}
@@ -60,7 +60,7 @@ class OZONE_EXPORT OzonePlatform {
// Ozone may retain this pointer for later use. An Ozone platform embedder
// must set this parameter in order for the Ozone platform implementation to
// be able to use Mojo.
- shell::Connector* connector = nullptr;
+ service_manager::Connector* connector = nullptr;
// Setting this to true indicates that the platform implementation should
// operate as a single process for platforms (i.e. drm) that are usually
@@ -108,12 +108,12 @@ class OZONE_EXPORT OzonePlatform {
// Ozone platform implementations may also choose to expose mojo interfaces to
// internal functionality. Embedders wishing to take advantage of ozone mojo
// implementations must invoke AddInterfaces with a valid
// shell::InterfaceRegistry* pointer to export all Mojo interfaces defined
// within Ozone.
//
// A default do-nothing implementation is provided to permit platform
// implementations to opt out of implementing any Mojo interfaces.
- virtual void AddInterfaces(shell::InterfaceRegistry* registry);
+ virtual void AddInterfaces(service_manager::InterfaceRegistry* registry);
private:
virtual void InitializeUI() = 0;
« no previous file with comments | « ui/ozone/platform/drm/ozone_platform_gbm.cc ('k') | ui/ozone/public/ozone_platform.cc » ('j') | no next file with comments »
@@ -108,12 +108,12 @@ class OZONE_EXPORT OzonePlatform {
// internal functionality. Embedders wishing to take advantage of ozone mojo
// implementations must invoke AddInterfaces with a valid
- // shell::InterfaceRegistry* pointer to export all Mojo interfaces defined
- // within Ozone.
+ // service_manager::InterfaceRegistry* pointer to export all Mojo interfaces
+ // defined within Ozone.
//
// A default do-nothing implementation is provided to permit platform

Powered by Google App Engine
This is Rietveld 408576698